summaryrefslogtreecommitdiffstats
path: root/usr.sbin/bhyve/pit_8254.c
diff options
context:
space:
mode:
Diffstat (limited to 'usr.sbin/bhyve/pit_8254.c')
-rw-r--r--usr.sbin/bhyve/pit_8254.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/usr.sbin/bhyve/pit_8254.c b/usr.sbin/bhyve/pit_8254.c
index 44d0cca..3987da3 100644
--- a/usr.sbin/bhyve/pit_8254.c
+++ b/usr.sbin/bhyve/pit_8254.c
@@ -153,10 +153,10 @@ pit_update_counter(struct counter *c, int latch)
* of the program.
*
* If the counter's initial value is not programmed we
* assume a value that would be set to generate 'guest_hz'
* interrupts per second.
*/
- c->initial = TIMER_DIV(PIT_8254_FREQ, guest_hz);
+ c->initial = TIMER_DIV(PIT_8254_FREQ, 100);
gettimeofday(&c->tv, NULL);
}
OpenPOWER on IntegriCloud
@@ -153,10 +153,10 @@ pit_update_counter(struct counter *c, int latch)
*
* If the counter's initial value is not programmed we
- * assume a value that would be set to generate 'guest_hz'
+ * assume a value that would be set to generate 100
* interrupts per second.
*/